/*
** Module   : DefinitionConstants.java
** Abstract : provides common string constants for XML definition files
**
** Copyright (c) 2009-2021, Golden Code Development Corporation.
**
** -#- -I- --Date-- ---------------------------------------Description----------------------------------------
** 001 GES 20090123 Provides common string constants for XML definition files.
** 002 CA  20210827 Refactored to allow other test types, beside terminal (which can be executed from the same 
**                  test suite).  Added SOAP and REST web service tests.
*/

/*
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU Affero General Public License as
** published by the Free Software Foundation, either version 3 of the
** License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package com.goldencode.harness;

/**
 * Provides common string constants for XML definition files.
 */
public interface DefinitionConstants
{
   /** The "test-plan" element tag. */
   public final String ELEM_TEST_PLAN = "test-plan";
   
   /** The "test-set" element tag. */
   public final String ELEM_TEST_SET = "test-set";
   
   /** The "project-index" element tag. */
   public final String ELEM_PROJECT_INDEX = "project-index";
   
   /** The "target" element tag. */
   public final String ELEM_TARGET = "target";
   
   /** The "test" element tag. */
   public final String ELEM_TEST = "test";

   /** The "rest" element tag. */
   public final String ELEM_REST = "rest";
   
   /** The "authorization" element tag. */
   public final String ELEM_AUTHORIZATION = "authorization";
   
   /** The "body" element tag. */
   public final String ELEM_BODY = "body";
   
   /** The "exact" element tag. */
   public final String ELEM_EXACT = "exact";
   
   /** The "exists" element tag. */
   public final String ELEM_EXISTS = "exists";
   
   /** The "header" element tag. */
   public final String ELEM_HEADER = "header";
   
   /** The "query" element tag. */
   public final String ELEM_QUERY = "query";
   
   /** The "regex" element tag. */
   public final String ELEM_REGEX = "regex";
   
   /** The "replace" element tag. */
   public final String ELEM_REPLACE = "replace";
   
   /** The "response" element tag. */
   public final String ELEM_RESPONSE = "response";
   
   /** The "status" element tag. */
   public final String ELEM_STATUS = "status";

   /** The "soap" element tag. */
   public final String ELEM_SOAP = "soap";

   /** The "include" element tag. */
   public final String ELEM_INCLUDE = "include";
   
   /** The "pause" element tag. */
   public final String ELEM_PAUSE = "pause";
   
   /** The "send-text" element tag. */
   public final String ELEM_SEND_TEXT = "send-text";
   
   /** The "send-special-key" element tag. */
   public final String ELEM_SEND_SPECIAL_KEY = "send-special-key";
   
   /** The "clear-screen-buffer" element tag. */
   public final String ELEM_CLEAR_SCREEN_BUFFER = "clear-screen-buffer";
   
   /** The "log-cursor-pos" element tag. */
   public final String ELEM_LOG_CURSOR_POS = "log-cursor-pos";
   
   /** The "check-cursor-pos" element tag. */
   public final String ELEM_CHECK_CURSOR_POS = "check-cursor-pos";
   
   /** The "log-screen-buffer" element tag. */
   public final String ELEM_LOG_SCREEN_BUFFER = "log-screen-buffer";
   
   /** The "wait-for-screen-buffer" element tag. */
   public final String ELEM_WAIT_FOR_SCREEN_BUFFER = "wait-for-screen-buffer";
   
   /** The "check-screen-buffer" element tag. */
   public final String ELEM_CHECK_SCREEN_BUFFER = "check-screen-buffer";
   
   /** The "output-directory" element tag. */
   public final String ELEM_OUTPUT_DIRECTORY = "output-directory";
   
   /** The "sftp" element tag. */
   public final String ELEM_SFTP = "sftp";
   
   /** The "ls" element tag. */
   public final String ELEM_LS = "ls";
   
   /** The "cd" element tag. */
   public final String ELEM_CD = "cd";
   
   /** The "lcd" element tag. */
   public final String ELEM_LCD = "lcd";
   
   /** The "pwd" element tag. */
   public final String ELEM_PWD = "pwd";
   
   /** The "lpwd" element tag. */
   public final String ELEM_LPWD = "lpwd";
   
   /** The "get" element tag. */
   public final String ELEM_GET = "get";
   
   /** The "put" element tag. */
   public final String ELEM_PUT = "put";
   
   /** The "symlink" element tag. */
   public final String ELEM_SYMLINK = "symlink";
   
   /** The "rename" element tag. */
   public final String ELEM_RENAME = "rename";
   
   /** The "rm" element tag. */
   public final String ELEM_RM = "rm";
   
   /** The "rmdir" element tag. */
   public final String ELEM_RMDIR = "rmdir";
   
   /** The "mkdir" element tag. */
   public final String ELEM_MKDIR = "mkdir";
   
   /** The "exclude" element tag. */
   public final String ELEM_EXCLUDE = "exclude";
   
   /** The "line" element tag. */
   public final String ELEM_LINE = "line";
   
   /** The "log" element tag. */
   public final String ELEM_LOG = "log";
   
   /** The "binary-file-comparison" element tag. */
   public final String ELEM_BINARY_FILE_COMPARISON = "binary-file-comparison";
   
   /** The "text-file-comparison" element tag. */
   public final String ELEM_TEXT_FILE_COMPARISON = "text-file-comparison";
   
   /** The "named-rectangles" element tag. */
   public final String ELEM_NAMED_RECTANGLES = "named-rectangles";
   
   /** The "rectangle" element tag. */
   public final String ELEM_RECTANGLE = "rectangle";
   
   /** The "paths" element tag. */
   public final String ELEM_PATHS = "paths";
   
   /** The "baseline" element tag. */
   public final String ELEM_BASELINE = "baseline";
   
   /** The "resources" element tag. */
   public final String ELEM_RESOURCES = "resources";
   
   /** The "create-mutex" element tag. */
   public final String ELEM_CREATE_MUTEX = "create-mutex";
   
   /** The "acquire-mutex" element tag. */
   public final String ELEM_ACQUIRE_MUTEX = "acquire-mutex";
   
   /** The "release-mutex" element tag. */
   public final String ELEM_RELEASE_MUTEX = "release-mutex";
   
   /** The "create-event-sem" element tag. */
   public final String ELEM_CREATE_EVENT_SEM = "create-event-sem";
   
   /** The "post-event-sem" element tag. */
   public final String ELEM_POST_EVENT_SEM = "post-event-sem";
   
   /** The "reset-event-sem" element tag. */
   public final String ELEM_RESET_EVENT_SEM = "reset-event-sem";
   
   /** The "wait-event-sem" element tag. */
   public final String ELEM_WAIT_EVENT_SEM = "wait-event-sem";
   
   /** The "check-post-count" element tag. */
   public final String ELEM_CHECK_POST_COUNT = "check-post-count";
   
   /** The "variable" element tag. */
   public final String ELEM_VARIABLE = "variable";
   
   /** The "parameter" element tag. */
   public final String ELEM_PARAMETER = "parameter";
   
   /** The "substitution" element tag. */
   public final String ELEM_SUBSTITUTION = "substitution";
   
   /** The "run-code" element tag. */
   public final String ELEM_RUN_CODE = "run-code";
   
   /** The "check-variable" attribute name. */
   public final String ELEM_CHECK_VARIABLE = "check-variable";
   
   /** The "read-cursor-pos" attribute name. */
   public final String ELEM_READ_CURSOR_POS = "read-cursor-pos";
   
   /** The "read-screen-buffer" attribute name. */
   public final String ELEM_READ_SCREEN_BUFFER = "read-screen-buffer";
   
   /** The "read-string" attribute name. */
   public final String ELEM_READ_STRING = "read-string";
   
   /** The "import" element tag. */
   public final String ELEM_IMPORT = "import";
   
   /** The "defaults" element name. */
   public final String ELEM_DEFAULTS = "defaults";
   
   /** The "attribute" element name. */
   public final String ELEM_ATTRIBUTE = "attribute";
   
   /** The "name" attribute name. */
   public final String ATTR_NAME = "name"; 
   
   /** The "code" attribute name. */
   public final String ATTR_CODE = "code";
   
   /** The "description" attribute name. */
   public final String ATTR_DESCR = "description";
   
   /** The "filename" attribute name. */
   public final String ATTR_FILENAME = "filename";
   
   /** The "filespec" attribute name. */
   public final String ATTR_FILESPEC = "filespec";
   
   /** The "method" attribute name. */
   public final String ATTR_METHOD = "method";
   
   /** The "path" attribute name. */
   public final String ATTR_PATH = "path";

   /** The "reason" attribute name. */
   public final String ATTR_REASON = "reason";
   
   /** The "save" attribute name. */
   public final String ATTR_SAVE = "save";
   
   /** The "service" attribute name. */
   public final String ATTR_SERVICE = "service";
   
   /** The "endpoint" attribute name. */
   public final String ATTR_ENDPOINT = "endpoint";

   /** The "ssl_accept_all" attribute name. */
   public final String ATTR_SSL_ACCEPT_ALL = "ssl_accept_all";

   /** The "ssl_accept_self_signed" attribute name. */
   public final String ATTR_SSL_ACCEPT_SELF_SIGNED = "ssl_accept_self_signed";

   /** The "ssl_truststore_file" attribute name. */
   public final String ATTR_SSL_TRUSTSTORE_FILE = "ssl_truststore_file";

   /** The "ssl_truststore_password" attribute name. */
   public final String ATTR_SSL_TRUSTSTORE_PASSWORD = "ssl_truststore_password";
   
   /** The "threads" attribute name. */
   public final String ATTR_THREADS = "threads"; 
   
   /** The "host" attribute name. */
   public final String ATTR_HOST = "host"; 
   
   /** The "port" attribute name. */
   public final String ATTR_PORT = "port"; 

   /** The "userid" attribute name. */
   public final String ATTR_USERID = "userid"; 

   /** The "password" attribute name. */
   public final String ATTR_PASSWORD = "password"; 

   /** The "term-type" attribute name. */
   public final String ATTR_TERM_TYPE = "term-type"; 

   /** The "term-columns" attribute name. */
   public final String ATTR_TERM_COLS = "term-columns"; 

   /** The "term-rows" attribute name. */
   public final String ATTR_TERM_ROWS = "term-rows"; 

   /** The "protocol" attribute name. */
   public final String ATTR_PROTOCOL = "protocol";
   
   /** The "millis" attribute name. */
   public final String ATTR_MILLIS = "millis"; 
   
   /** The "value" attribute name. */
   public final String ATTR_VALUE = "value"; 
   
   /** The "modifiers" attribute name. */
   public final String ATTR_MODIFIERS = "modifiers"; 
   
   /** The "delay" attribute name. */
   public final String ATTR_DELAY = "delay";
   
   /** The "interval" attribute name. */
   public final String ATTR_INTERVAL = "interval";
   
   /** The "timeout" attribute name. */
   public final String ATTR_TIMEOUT = "timeout";
   
   /** The "minimum" attribute name. */
   public final String ATTR_MINIMUM = "minimum";
   
   /** The "wait" attribute name. */
   public final String ATTR_WAIT = "wait";
   
   /** The "row" attribute name. */
   public final String ATTR_ROW = "row"; 
   
   /** The "column" attribute name. */
   public final String ATTR_COLUMN = "column";
   
   /** The "width" attribute name. */
   public final String ATTR_WIDTH = "width"; 
   
   /** The "height" attribute name. */
   public final String ATTR_HEIGHT = "height"; 
   
   /** The "clear" attribute name. */
   public final String ATTR_CLEAR = "clear";
   
   /** The "left" attribute name. */
   public final String ATTR_LEFT = "left"; 
   
   /** The "right" attribute name. */
   public final String ATTR_RIGHT = "right"; 
   
   /** The "top" attribute name. */
   public final String ATTR_TOP = "top"; 
   
   /** The "bottom" attribute name. */
   public final String ATTR_BOTTOM = "bottom";
   
   /** The "special" attribute name. */
   public final String ATTR_SPECIAL = "special";
   
   /** The "repeat" attribute name. */
   public final String ATTR_REPEAT = "repeat";
   
   /** The "local" attribute name. */
   public final String ATTR_LOCAL = "local";
   
   /** The "remote" attribute name. */
   public final String ATTR_REMOTE = "remote";
   
   /** The "old" attribute name. */
   public final String ATTR_OLD = "old";
   
   /** The "new" attribute name. */
   public final String ATTR_NEW = "new";
   
   /** The "link" attribute name. */
   public final String ATTR_LINK = "link";
   
   /** The "actual" attribute name. */
   public final String ATTR_ACTUAL = "actual";
   
   /** The "baseline" attribute name. */
   public final String ATTR_BASELINE = "baseline";
   
   /** The "start" attribute name. */
   public final String ATTR_START = "start";
   
   /** The "end" attribute name. */
   public final String ATTR_END = "end";
   
   /** The "type" attribute name. */
   public final String ATTR_TYPE = "type";
   
   /** The "page-number" attribute name. */
   public final String ATTR_PAGE_NUMBER = "page-number";
   
   /** The "named-rectangle" attribute name. */
   public final String ATTR_NAMED_RECTANGLE = "named-rectangle";
   
   /** The "unique" attribute name. */
   public final String ATTR_UNIQUE = "unique";
   
   /** The "expected" attribute name. */
   public final String ATTR_EXPECTED = "expected";
   
   /** The "initial" attribute name. */
   public final String ATTR_INITIAL = "initial";
   
   /** The "variable" attribute name. */
   public final String ATTR_VARIABLE = "variable";
   
   /** The "row-variable" attribute name. */
   public final String ATTR_ROW_VARIABLE = "row-variable";
   
   /** The "column-variable" attribute name. */
   public final String ATTR_COLUMN_VARIABLE = "column-variable";
   
   /** The "spec" attribute name. */
   public final String ATTR_SPEC = "spec";
   
   /** The "debug" attribute name. */
   public final String ATTR_DEBUG = "debug";
   
   /** The "set" attribute name. */
   public final String ATTR_SET = "set";
   
   /** The "reset" attribute name. */
   public final String ATTR_RESET = "reset";
   
   /** The "dependency" attribute name. */
   public final String ATTR_DEPENDENCY = "dependency";
   
   /** The "group" attribute name. */
   public final String ATTR_GROUP = "group";
   
   /** The "referent" attribute name. */
   public final String ATTR_REFERENT = "referent";
   
   /** The "failure-mode" attribute name. */
   public final String ATTR_FAILURE_MODE = "failure-mode";
   
   /** The "backout" attribute name. */
   public final String ATTR_BACKOUT = "backout";
   
   /** The "ignore-size" attribute name. */
   public final String ATTR_IGNORE_SIZE = "ignore-size";
   
   /** The "prompt" attribute name. */
   public final String ATTR_PROMPT = "prompt";
   
   /** The "prompt-secret" attribute name. */
   public final String ATTR_PROMPT_SECRET = "prompt-secret";   
}
