/*
** Module   : TestExecutor.java
** Abstract : A generic test executor. 
**
** Copyright (c) 2021, Golden Code Development Corporation.
**
** -#- -I- --Date-- ---------------------------------------Description----------------------------------------
** 001 CA  20210827 Created initial version.
*/

/*
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU Affero General Public License as
** published by the Free Software Foundation, either version 3 of the
** License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package com.goldencode.harness;

import com.goldencode.harness.test.*;

/**
 * An executor for {@link Testable tests}.
 */
public class TestExecutor
{
   /**
    * Execute the specified test.
    * 
    * @param    test
    *           The test to execute.
    */
   public void execute(Testable test)
   {
      test.execute();
   }
   
   /**
    * Check the pre-condition of this test.
    * 
    * @return   Always <code>true</code>.
    */
   public boolean pre()
   {
      return true;
   }
   
   /**
    * Post-processing of this test (no-op by default).
    */
   public void post()
   {
      // no-op
   }
}
