/*
** Module   : DynamicCode.java
** Abstract : mechanism for calling arbitrary code during a test
**
** Copyright (c) 2009, Golden Code Development Corporation.
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 GES 20090226 Mechanism for calling arbitrary code during a test.
*/

/*
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU Affero General Public License as
** published by the Free Software Foundation, either version 3 of the
** License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package com.goldencode.harness.test;

import com.goldencode.harness.*;
import com.goldencode.harness.terminal.*;

/**
 * Mechanism for calling arbitrary code during a test.
 */
public interface DynamicCode
{
   /**
    * Run arbitrary code accessing any shared resources as needed.
    *
    * @param    vars
    *           Variables used in this method.
    * @param    term
    *           The terminal that represents the system under test.
    * @param    sb
    *           Output buffer for any text that should be stored for inclusion
    *           in reports.
    */
   public void execute(Variable[] vars, Terminal term, StringBuilder sb);
}
