/*
** Module   : SftpConnect.java
** Abstract : directive to connect to the target system via SFTP
**
** Copyright (c) 2009-2021, Golden Code Development Corporation.
**
** -#- -I- --Date-- ---------------------------------------Description----------------------------------------
** 001 GES 20090126 Directive to connect to the target system via SFTP.
** 002 CA  20210827 Refactored to allow other test types, beside terminal (which can be executed from the same 
**                  test suite).  Added SOAP and REST web service tests.
*/

/*
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU Affero General Public License as
** published by the Free Software Foundation, either version 3 of the
** License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package com.goldencode.harness.test;

import com.goldencode.harness.*;
import com.goldencode.harness.transport.*;

/**
 * Directive to connect to the target system via SFTP.
 */
public class SftpConnect
extends Report
implements Testable
{
   /** Short name for the activity. */
   private static final String NAME = "SFTP-CONNECT";
   
   /** Helper shared by all steps that are part of the same SFTP session. */
   private final SFTPSession sftp;
   
   /**
    * Constructor.
    *
    * @param    sftp
    *           Helper shared by all steps that are part of the same SFTP
    *           session.
    */
   public SftpConnect(SFTPSession sftp)
   {
      super(NAME, "");
      this.sftp = sftp;
   }
   
   /**
    * Execute the directive of the test using the given terminal as the data
    * sink and/or source for the operation.
    */
   @Override
   public void execute()
   {
      sftp.connect();
      setStatus(Status.PASSED, null);
   }
}
